@@ -23,7 +23,9 @@ log: logging.Logger = logging.getLogger(__name__)
 ENGINES = [
     Engine(name='query-engine', env='PRISMA_QUERY_ENGINE_BINARY'),
     Engine(name='migration-engine', env='PRISMA_MIGRATION_ENGINE_BINARY'),
-    Engine(name='introspection-engine', env='PRISMA_INTROSPECTION_ENGINE_BINARY'),
+    Engine(
+        name='introspection-engine', env='PRISMA_INTROSPECTION_ENGINE_BINARY'
+    ),
     Engine(name='prisma-fmt', env='PRISMA_FMT_BINARY'),
 ]
 
