@@ -9,7 +9,7 @@ from ...utils import maybe_async_run, temp_env_update, module_exists
 
 @click.group()
 def cli() -> None:
-    """Commands for developing Prisma Python"""
+    """Commands for developing Prisma Client Python"""
 
 
 @cli.command()
@@ -18,7 +18,7 @@ def cli() -> None:
 def playground(schema: Optional[str], skip_generate: bool) -> None:
     """Run the GraphQL playground"""
     if skip_generate and not module_exists('prisma.client'):
-        error('Prisma Python has not been generated yet.')
+        error('Prisma Client Python has not been generated yet.')
     else:
         generate_client(schema=schema, reload=True)
 
